@@ -181,8 +181,11 @@ class Image(object):
 
         result = []
         for thing in env:
-            if '=' in env:
+            if '=' in thing:
                 result.append(thing)
+            elif ":" in thing:
+                name, dflt = thing.split(":", 1)
+                result.append("{0}={1}".format(name, os.environ.get(name, dflt)))
             else:
                 result.append("{0}={1}".format(thing, os.environ[thing]))
         return result
@@ -284,7 +287,7 @@ class Image(object):
         if volumes:
             log.info("\tUsing volumes\tvolumes=%s", volumes)
         if env:
-            log.info("\tUsing environment\tenv=%s", env)
+            log.info("\tUsing environment\tenv=%s", [thing.split('=', 1)[0] for thing in env])
         if ports:
             log.info("\tUsing ports\tports=%s", ports.keys())
         container = self.docker_context.create_container(image_name
